==> onos-yang-serializers-xml-2.3-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeconnectivitymatrix/ConnectivityMatrixKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconnectivitymatrix;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of connectivityMatrix.
 */
public class ConnectivityMatrixKeys implements KeyInfo<DefaultConnectivityMatrix> {
    protected long id;
    /**
     * Returns the attribute id.
     *
     * @return id value of id
     */
    public long id() {
        return id;
    }

    /**
     * Sets the value to attribute id.
     *
     * @param id value of id
     */
    public void id(long id) {
        this.id = id;
    }


    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ConnectivityMatrixKeys) {
            ConnectivityMatrixKeys other = (ConnectivityMatrixKeys) obj;
            return
                Objects.equals(id, other.id);
        }
        return false;
    }
}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tenodeconnectivitymatrix/ConnectivityMatrixKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tenodeconnectivitymatrix;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of connectivityMatrix.
 */
public class ConnectivityMatrixKeys implements KeyInfo<DefaultConnectivityMatrix> {
    protected long id;
    /**
     * Returns the attribute id.
     *
     * @return id value of id
     */
    public long id() {
        return id;
    }

    /**
     * Sets the value to attribute id.
     *
     * @param id value of id
     */
    public void id(long id) {
        this.id = id;
    }


    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ConnectivityMatrixKeys) {
            ConnectivityMatrixKeys other = (ConnectivityMatrixKeys) obj;
            return
                Objects.deepEquals(id, other.id);
        }
        return false;
    }
}
